"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iot.broker.v1.broker_pb2
import yandex.cloud.iot.broker.v1.broker_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class BrokerServiceStub:
    """A set of methods for managing broker."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.GetBrokerRequest,
        yandex.cloud.iot.broker.v1.broker_pb2.Broker,
    ]
    """Returns the specified broker.

    To get the list of available brokers, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokersRequest,
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokersResponse,
    ]
    """Retrieves the list of brokers in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.CreateBrokerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a broker in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.UpdateBrokerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified broker."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.DeleteBrokerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified broker."""

    ListCertificates: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerCertificatesRequest,
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerCertificatesResponse,
    ]
    """Retrieves the list of broker certificates for the specified broker."""

    AddCertificate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.AddBrokerCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a certificate."""

    DeleteCertificate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.DeleteBrokerCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified broker certificate."""

    ListPasswords: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerPasswordsRequest,
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerPasswordsResponse,
    ]
    """Retrieves the list of passwords for the specified broker."""

    AddPassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.AddBrokerPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds password for the specified broker."""

    DeletePassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.DeleteBrokerPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified password."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerOperationsRequest,
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerOperationsResponse,
    ]
    """Lists operations for the specified broker."""

class BrokerServiceAsyncStub:
    """A set of methods for managing broker."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.GetBrokerRequest,
        yandex.cloud.iot.broker.v1.broker_pb2.Broker,
    ]
    """Returns the specified broker.

    To get the list of available brokers, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokersRequest,
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokersResponse,
    ]
    """Retrieves the list of brokers in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.CreateBrokerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a broker in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.UpdateBrokerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified broker."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.DeleteBrokerRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified broker."""

    ListCertificates: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerCertificatesRequest,
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerCertificatesResponse,
    ]
    """Retrieves the list of broker certificates for the specified broker."""

    AddCertificate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.AddBrokerCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a certificate."""

    DeleteCertificate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.DeleteBrokerCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified broker certificate."""

    ListPasswords: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerPasswordsRequest,
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerPasswordsResponse,
    ]
    """Retrieves the list of passwords for the specified broker."""

    AddPassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.AddBrokerPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds password for the specified broker."""

    DeletePassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.DeleteBrokerPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified password."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerOperationsRequest,
        yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerOperationsResponse,
    ]
    """Lists operations for the specified broker."""

class BrokerServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing broker."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.GetBrokerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.broker.v1.broker_pb2.Broker, collections.abc.Awaitable[yandex.cloud.iot.broker.v1.broker_pb2.Broker]]:
        """Returns the specified broker.

        To get the list of available brokers, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokersRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokersResponse, collections.abc.Awaitable[yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokersResponse]]:
        """Retrieves the list of brokers in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.CreateBrokerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a broker in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.UpdateBrokerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified broker."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.DeleteBrokerRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified broker."""

    @abc.abstractmethod
    def ListCertificates(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerCertificatesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerCertificatesResponse, collections.abc.Awaitable[yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerCertificatesResponse]]:
        """Retrieves the list of broker certificates for the specified broker."""

    @abc.abstractmethod
    def AddCertificate(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.AddBrokerCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds a certificate."""

    @abc.abstractmethod
    def DeleteCertificate(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.DeleteBrokerCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified broker certificate."""

    @abc.abstractmethod
    def ListPasswords(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerPasswordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerPasswordsResponse, collections.abc.Awaitable[yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerPasswordsResponse]]:
        """Retrieves the list of passwords for the specified broker."""

    @abc.abstractmethod
    def AddPassword(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.AddBrokerPasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds password for the specified broker."""

    @abc.abstractmethod
    def DeletePassword(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.DeleteBrokerPasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified password."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerOperationsResponse, collections.abc.Awaitable[yandex.cloud.iot.broker.v1.broker_service_pb2.ListBrokerOperationsResponse]]:
        """Lists operations for the specified broker."""

def add_BrokerServiceServicer_to_server(servicer: BrokerServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/mysql/v1/user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/mdb/mysql/v1/user.proto\x12\x19yandex.cloud.mdb.mysql.v1\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xbb\x02\n\x04User\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12:\n\x0bpermissions\x18\x03 \x03(\x0b\x32%.yandex.cloud.mdb.mysql.v1.Permission\x12G\n\x12global_permissions\x18\x04 \x03(\x0e\x32+.yandex.cloud.mdb.mysql.v1.GlobalPermission\x12\x46\n\x11\x63onnection_limits\x18\x05 \x01(\x0b\x32+.yandex.cloud.mdb.mysql.v1.ConnectionLimits\x12\x44\n\x15\x61uthentication_plugin\x18\x06 \x01(\x0e\x32%.yandex.cloud.mdb.mysql.v1.AuthPlugin\"\xaf\x03\n\nPermission\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12G\n\x05roles\x18\x02 \x03(\x0e\x32/.yandex.cloud.mdb.mysql.v1.Permission.PrivilegeB\x07\x82\xc8\x31\x03>=1\"\xc0\x02\n\tPrivilege\x12\x19\n\x15PRIVILEGE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x41LL_PRIVILEGES\x10\x01\x12\t\n\x05\x41LTER\x10\x02\x12\x11\n\rALTER_ROUTINE\x10\x03\x12\n\n\x06\x43REATE\x10\x04\x12\x12\n\x0e\x43REATE_ROUTINE\x10\x05\x12\x1b\n\x17\x43REATE_TEMPORARY_TABLES\x10\x06\x12\x0f\n\x0b\x43REATE_VIEW\x10\x07\x12\n\n\x06\x44\x45LETE\x10\x08\x12\x08\n\x04\x44ROP\x10\t\x12\t\n\x05\x45VENT\x10\n\x12\x0b\n\x07\x45XECUTE\x10\x0b\x12\t\n\x05INDEX\x10\x0c\x12\n\n\x06INSERT\x10\r\x12\x0f\n\x0bLOCK_TABLES\x10\x0e\x12\n\n\x06SELECT\x10\x0f\x12\r\n\tSHOW_VIEW\x10\x10\x12\x0b\n\x07TRIGGER\x10\x11\x12\n\n\x06UPDATE\x10\x12\x12\x0e\n\nREFERENCES\x10\x13\"\xa8\x02\n\x10\x43onnectionLimits\x12\x44\n\x16max_questions_per_hour\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x42\n\x14max_updates_per_hour\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x46\n\x18max_connections_per_hour\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\x12\x42\n\x14max_user_connections\x18\x04 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueB\x07\xfa\xc7\x31\x03>=0\"\xec\x02\n\x08UserSpec\x12,\n\x04name\x18\x01 \x01(\tB\x1e\xe8\xc7\x31\x01\xf2\xc7\x31\x0e[a-zA-Z0-9_-]*\x8a\xc8\x31\x04<=32\x12\x1f\n\x08password\x18\x02 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05\x38-128\x12:\n\x0bpermissions\x18\x03 \x03(\x0b\x32%.yandex.cloud.mdb.mysql.v1.Permission\x12G\n\x12global_permissions\x18\x04 \x03(\x0e\x32+.yandex.cloud.mdb.mysql.v1.GlobalPermission\x12\x46\n\x11\x63onnection_limits\x18\x05 \x01(\x0b\x32+.yandex.cloud.mdb.mysql.v1.ConnectionLimits\x12\x44\n\x15\x61uthentication_plugin\x18\x06 \x01(\x0e\x32%.yandex.cloud.mdb.mysql.v1.AuthPlugin*\x9e\x01\n\x10GlobalPermission\x12!\n\x1dGLOBAL_PERMISSION_UNSPECIFIED\x10\x00\x12\x16\n\x12REPLICATION_CLIENT\x10\x01\x12\x15\n\x11REPLICATION_SLAVE\x10\x02\x12\x0b\n\x07PROCESS\x10\x03\x12\x19\n\x15\x46LUSH_OPTIMIZER_COSTS\x10\x04\x12\x10\n\x0cSHOW_ROUTINE\x10\x05*t\n\nAuthPlugin\x12\x1b\n\x17\x41UTH_PLUGIN_UNSPECIFIED\x10\x00\x12\x19\n\x15MYSQL_NATIVE_PASSWORD\x10\x01\x12\x19\n\x15\x43\x41\x43HING_SHA2_PASSWORD\x10\x02\x12\x13\n\x0fSHA256_PASSWORD\x10\x03\x42\x64\n\x1dyandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysqlb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.mysql.v1.user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.mysql.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/mysql/v1;mysql'
  _PERMISSION.fields_by_name['roles']._options = None
  _PERMISSION.fields_by_name['roles']._serialized_options = b'\202\3101\003>=1'
  _CONNECTIONLIMITS.fields_by_name['max_questions_per_hour']._options = None
  _CONNECTIONLIMITS.fields_by_name['max_questions_per_hour']._serialized_options = b'\372\3071\003>=0'
  _CONNECTIONLIMITS.fields_by_name['max_updates_per_hour']._options = None
  _CONNECTIONLIMITS.fields_by_name['max_updates_per_hour']._serialized_options = b'\372\3071\003>=0'
  _CONNECTIONLIMITS.fields_by_name['max_connections_per_hour']._options = None
  _CONNECTIONLIMITS.fields_by_name['max_connections_per_hour']._serialized_options = b'\372\3071\003>=0'
  _CONNECTIONLIMITS.fields_by_name['max_user_connections']._options = None
  _CONNECTIONLIMITS.fields_by_name['max_user_connections']._serialized_options = b'\372\3071\003>=0'
  _USERSPEC.fields_by_name['name']._options = None
  _USERSPEC.fields_by_name['name']._serialized_options = b'\350\3071\001\362\3071\016[a-zA-Z0-9_-]*\212\3101\004<=32'
  _USERSPEC.fields_by_name['password']._options = None
  _USERSPEC.fields_by_name['password']._serialized_options = b'\350\3071\001\212\3101\0058-128'
  _globals['_GLOBALPERMISSION']._serialized_start=1549
  _globals['_GLOBALPERMISSION']._serialized_end=1707
  _globals['_AUTHPLUGIN']._serialized_start=1709
  _globals['_AUTHPLUGIN']._serialized_end=1825
  _globals['_USER']._serialized_start=131
  _globals['_USER']._serialized_end=446
  _globals['_PERMISSION']._serialized_start=449
  _globals['_PERMISSION']._serialized_end=880
  _globals['_PERMISSION_PRIVILEGE']._serialized_start=560
  _globals['_PERMISSION_PRIVILEGE']._serialized_end=880
  _globals['_CONNECTIONLIMITS']._serialized_start=883
  _globals['_CONNECTIONLIMITS']._serialized_end=1179
  _globals['_USERSPEC']._serialized_start=1182
  _globals['_USERSPEC']._serialized_end=1546
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/storage/v1/bucket_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.storage.v1 import bucket_pb2 as yandex_dot_cloud_dot_storage_dot_v1_dot_bucket__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,yandex/cloud/storage/v1/bucket_service.proto\x12\x17yandex.cloud.storage.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a$yandex/cloud/storage/v1/bucket.proto\x1a\x1dyandex/cloud/validation.proto\"\xaf\x01\n\x10GetBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\x04view\x18\x02 \x01(\x0e\x32..yandex.cloud.storage.v1.GetBucketRequest.View\"I\n\x04View\x12\x14\n\x10VIEW_UNSPECIFIED\x10\x00\x12\x0e\n\nVIEW_BASIC\x10\x01\x12\x0c\n\x08VIEW_ACL\x10\x02\x12\r\n\tVIEW_FULL\x10\x03\"5\n\x12ListBucketsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"G\n\x13ListBucketsResponse\x12\x30\n\x07\x62uckets\x18\x01 \x03(\x0b\x32\x1f.yandex.cloud.storage.v1.Bucket\"\xa7\x02\n\x13\x43reateBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1f\n\tfolder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\x15\x64\x65\x66\x61ult_storage_class\x18\x04 \x01(\t\x12\x10\n\x08max_size\x18\x05 \x01(\x03\x12M\n\x16\x61nonymous_access_flags\x18\x06 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12)\n\x03\x61\x63l\x18\x07 \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.ACL\x12*\n\x04tags\x18\x08 \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.TagJ\x04\x08\x03\x10\x04\"$\n\x14\x43reateBucketMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc2\x05\n\x13UpdateBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x35\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMaskB\x04\xe8\xc7\x31\x01\x12M\n\x16\x61nonymous_access_flags\x18\x03 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12\x1d\n\x15\x64\x65\x66\x61ult_storage_class\x18\x04 \x01(\t\x12\x10\n\x08max_size\x18\x05 \x01(\x03\x12/\n\x04\x63ors\x18\x06 \x03(\x0b\x32!.yandex.cloud.storage.v1.CorsRule\x12\x42\n\x10website_settings\x18\x07 \x01(\x0b\x32(.yandex.cloud.storage.v1.WebsiteSettings\x12\x37\n\nversioning\x18\x08 \x01(\x0e\x32#.yandex.cloud.storage.v1.Versioning\x12?\n\x0flifecycle_rules\x18\t \x03(\x0b\x32&.yandex.cloud.storage.v1.LifecycleRule\x12\'\n\x06policy\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x03\x61\x63l\x18\x0b \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.ACL\x12*\n\x04tags\x18\x0c \x03(\x0b\x32\x1c.yandex.cloud.storage.v1.Tag\x12\x38\n\x0bobject_lock\x18\r \x01(\x0b\x32#.yandex.cloud.storage.v1.ObjectLock\x12\x37\n\nencryption\x18\x0e \x01(\x0b\x32#.yandex.cloud.storage.v1.Encryption\"$\n\x14UpdateBucketMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\")\n\x13\x44\x65leteBucketRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"$\n\x14\x44\x65leteBucketMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"+\n\x15GetBucketStatsRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"1\n\x1bGetBucketHTTPSConfigRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"n\n\x1cSelfManagedHTTPSConfigParams\x12&\n\x0f\x63\x65rtificate_pem\x18\x01 \x01(\tB\r\x8a\xc8\x31\t<=3145728\x12&\n\x0fprivate_key_pem\x18\x02 \x01(\tB\r\x8a\xc8\x31\t<=3145728\"=\n#CertificateManagerHTTPSConfigParams\x12\x16\n\x0e\x63\x65rtificate_id\x18\x01 \x01(\t\"\xed\x01\n\x1bSetBucketHTTPSConfigRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12M\n\x0cself_managed\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.storage.v1.SelfManagedHTTPSConfigParamsH\x00\x12[\n\x13\x63\x65rtificate_manager\x18\x03 \x01(\x0b\x32<.yandex.cloud.storage.v1.CertificateManagerHTTPSConfigParamsH\x00\x42\x0e\n\x06params\x12\x04\xc0\xc1\x31\x01\",\n\x1cSetBucketHTTPSConfigMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t\"4\n\x1e\x44\x65leteBucketHTTPSConfigRequest\x12\x12\n\x04name\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"/\n\x1f\x44\x65leteBucketHTTPSConfigMetadata\x12\x0c\n\x04name\x18\x01 \x01(\t2\xe1\x0b\n\rBucketService\x12~\n\x04List\x12+.yandex.cloud.storage.v1.ListBucketsRequest\x1a,.yandex.cloud.storage.v1.ListBucketsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/storage/v1/buckets\x12u\n\x03Get\x12).yandex.cloud.storage.v1.GetBucketRequest\x1a\x1f.yandex.cloud.storage.v1.Bucket\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/storage/v1/buckets/{name}\x12\x9b\x01\n\x06\x43reate\x12,.yandex.cloud.storage.v1.CreateBucketRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x1e\n\x14\x43reateBucketMetadata\x12\x06\x42ucket\x82\xd3\xe4\x93\x02\x18\"\x13/storage/v1/buckets:\x01*\x12\xa2\x01\n\x06Update\x12,.yandex.cloud.storage.v1.UpdateBucketRequest\x1a!.yandex.cloud.operation.Operation\"G\xb2\xd2*\x1e\n\x14UpdateBucketMetadata\x12\x06\x42ucket\x82\xd3\xe4\x93\x02\x1f\x32\x1a/storage/v1/buckets/{name}:\x01*\x12\xae\x01\n\x06\x44\x65lete\x12,.yandex.cloud.storage.v1.DeleteBucketRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2*-\n\x14\x44\x65leteBucketMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1c*\x1a/storage/v1/buckets/{name}\x12\x8d\x01\n\x08GetStats\x12..yandex.cloud.storage.v1.GetBucketStatsRequest\x1a$.yandex.cloud.storage.v1.BucketStats\"+\x82\xd3\xe4\x93\x02%\x12#/storage/v1/buckets/{name}:getStats\x12\x9f\x01\n\x0eGetHTTPSConfig\x12\x34.yandex.cloud.storage.v1.GetBucketHTTPSConfigRequest\x1a$.yandex.cloud.storage.v1.HTTPSConfig\"1\x82\xd3\xe4\x93\x02+\x12)/storage/v1/buckets/{name}:getHttpsConfig\x12\xce\x01\n\x0eSetHTTPSConfig\x12\x34.yandex.cloud.storage.v1.SetBucketHTTPSConfigRequest\x1a!.yandex.cloud.operation.Operation\"c\xb2\xd2*+\n\x1cSetBucketHTTPSConfigMetadata\x12\x0bHTTPSConfig\x82\xd3\xe4\x93\x02.\")/storage/v1/buckets/{name}:setHttpsConfig:\x01*\x12\xe1\x01\n\x11\x44\x65leteHTTPSConfig\x12\x37.yandex.cloud.storage.v1.DeleteBucketHTTPSConfigRequest\x1a!.yandex.cloud.operation.Operation\"p\xb2\xd2*8\n\x1f\x44\x65leteBucketHTTPSConfigMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02.\",/storage/v1/buckets/{name}:deleteHttpsConfigBb\n\x1byandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.storage.v1.bucket_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storage'
  _GETBUCKETREQUEST.fields_by_name['name']._options = None
  _GETBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _LISTBUCKETSREQUEST.fields_by_name['folder_id']._options = None
  _LISTBUCKETSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEBUCKETREQUEST.fields_by_name['name']._options = None
  _CREATEBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _CREATEBUCKETREQUEST.fields_by_name['folder_id']._options = None
  _CREATEBUCKETREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEBUCKETREQUEST.fields_by_name['name']._options = None
  _UPDATEBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _UPDATEBUCKETREQUEST.fields_by_name['update_mask']._options = None
  _UPDATEBUCKETREQUEST.fields_by_name['update_mask']._serialized_options = b'\350\3071\001'
  _DELETEBUCKETREQUEST.fields_by_name['name']._options = None
  _DELETEBUCKETREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _GETBUCKETSTATSREQUEST.fields_by_name['name']._options = None
  _GETBUCKETSTATSREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _GETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._options = None
  _GETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['certificate_pem']._options = None
  _SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['certificate_pem']._serialized_options = b'\212\3101\t<=3145728'
  _SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['private_key_pem']._options = None
  _SELFMANAGEDHTTPSCONFIGPARAMS.fields_by_name['private_key_pem']._serialized_options = b'\212\3101\t<=3145728'
  _SETBUCKETHTTPSCONFIGREQUEST.oneofs_by_name['params']._options = None
  _SETBUCKETHTTPSCONFIGREQUEST.oneofs_by_name['params']._serialized_options = b'\300\3011\001'
  _SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._options = None
  _SETBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _DELETEBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._options = None
  _DELETEBUCKETHTTPSCONFIGREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001'
  _BUCKETSERVICE.methods_by_name['List']._options = None
  _BUCKETSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/storage/v1/buckets'
  _BUCKETSERVICE.methods_by_name['Get']._options = None
  _BUCKETSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/storage/v1/buckets/{name}'
  _BUCKETSERVICE.methods_by_name['Create']._options = None
  _BUCKETSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreateBucketMetadata\022\006Bucket\202\323\344\223\002\030\"\023/storage/v1/buckets:\001*'
  _BUCKETSERVICE.methods_by_name['Update']._options = None
  _BUCKETSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateBucketMetadata\022\006Bucket\202\323\344\223\002\0372\032/storage/v1/buckets/{name}:\001*'
  _BUCKETSERVICE.methods_by_name['Delete']._options = None
  _BUCKETSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteBucketMetadata\022\025google.protobuf.Empty\202\323\344\223\002\034*\032/storage/v1/buckets/{name}'
  _BUCKETSERVICE.methods_by_name['GetStats']._options = None
  _BUCKETSERVICE.methods_by_name['GetStats']._serialized_options = b'\202\323\344\223\002%\022#/storage/v1/buckets/{name}:getStats'
  _BUCKETSERVICE.methods_by_name['GetHTTPSConfig']._options = None
  _BUCKETSERVICE.methods_by_name['GetHTTPSConfig']._serialized_options = b'\202\323\344\223\002+\022)/storage/v1/buckets/{name}:getHttpsConfig'
  _BUCKETSERVICE.methods_by_name['SetHTTPSConfig']._options = None
  _BUCKETSERVICE.methods_by_name['SetHTTPSConfig']._serialized_options = b'\262\322*+\n\034SetBucketHTTPSConfigMetadata\022\013HTTPSConfig\202\323\344\223\002.\")/storage/v1/buckets/{name}:setHttpsConfig:\001*'
  _BUCKETSERVICE.methods_by_name['DeleteHTTPSConfig']._options = None
  _BUCKETSERVICE.methods_by_name['DeleteHTTPSConfig']._serialized_options = b'\262\322*8\n\037DeleteBucketHTTPSConfigMetadata\022\025google.protobuf.Empty\202\323\344\223\002.\",/storage/v1/buckets/{name}:deleteHttpsConfig'
  _globals['_GETBUCKETREQUEST']._serialized_start=311
  _globals['_GETBUCKETREQUEST']._serialized_end=486
  _globals['_GETBUCKETREQUEST_VIEW']._serialized_start=413
  _globals['_GETBUCKETREQUEST_VIEW']._serialized_end=486
  _globals['_LISTBUCKETSREQUEST']._serialized_start=488
  _globals['_LISTBUCKETSREQUEST']._serialized_end=541
  _globals['_LISTBUCKETSRESPONSE']._serialized_start=543
  _globals['_LISTBUCKETSRESPONSE']._serialized_end=614
  _globals['_CREATEBUCKETREQUEST']._serialized_start=617
  _globals['_CREATEBUCKETREQUEST']._serialized_end=912
  _globals['_CREATEBUCKETMETADATA']._serialized_start=914
  _globals['_CREATEBUCKETMETADATA']._serialized_end=950
  _globals['_UPDATEBUCKETREQUEST']._serialized_start=953
  _globals['_UPDATEBUCKETREQUEST']._serialized_end=1659
  _globals['_UPDATEBUCKETMETADATA']._serialized_start=1661
  _globals['_UPDATEBUCKETMETADATA']._serialized_end=1697
  _globals['_DELETEBUCKETREQUEST']._serialized_start=1699
  _globals['_DELETEBUCKETREQUEST']._serialized_end=1740
  _globals['_DELETEBUCKETMETADATA']._serialized_start=1742
  _globals['_DELETEBUCKETMETADATA']._serialized_end=1778
  _globals['_GETBUCKETSTATSREQUEST']._serialized_start=1780
  _globals['_GETBUCKETSTATSREQUEST']._serialized_end=1823
  _globals['_GETBUCKETHTTPSCONFIGREQUEST']._serialized_start=1825
  _globals['_GETBUCKETHTTPSCONFIGREQUEST']._serialized_end=1874
  _globals['_SELFMANAGEDHTTPSCONFIGPARAMS']._serialized_start=1876
  _globals['_SELFMANAGEDHTTPSCONFIGPARAMS']._serialized_end=1986
  _globals['_CERTIFICATEMANAGERHTTPSCONFIGPARAMS']._serialized_start=1988
  _globals['_CERTIFICATEMANAGERHTTPSCONFIGPARAMS']._serialized_end=2049
  _globals['_SETBUCKETHTTPSCONFIGREQUEST']._serialized_start=2052
  _globals['_SETBUCKETHTTPSCONFIGREQUEST']._serialized_end=2289
  _globals['_SETBUCKETHTTPSCONFIGMETADATA']._serialized_start=2291
  _globals['_SETBUCKETHTTPSCONFIGMETADATA']._serialized_end=2335
  _globals['_DELETEBUCKETHTTPSCONFIGREQUEST']._serialized_start=2337
  _globals['_DELETEBUCKETHTTPSCONFIGREQUEST']._serialized_end=2389
  _globals['_DELETEBUCKETHTTPSCONFIGMETADATA']._serialized_start=2391
  _globals['_DELETEBUCKETHTTPSCONFIGMETADATA']._serialized_end=2438
  _globals['_BUCKETSERVICE']._serialized_start=2441
  _globals['_BUCKETSERVICE']._serialized_end=3946
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ydb/v1/database_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.ydb.v1 import database_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_database__pb2
from yandex.cloud.ydb.v1 import backup_pb2 as yandex_dot_cloud_dot_ydb_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*yandex/cloud/ydb/v1/database_service.proto\x12\x13yandex.cloud.ydb.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a\"yandex/cloud/ydb/v1/database.proto\x1a yandex/cloud/ydb/v1/backup.proto\"e\n\x13MoveDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12+\n\x15\x64\x65stination_folder_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"B\n\x14MoveDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"\x89\x01\n\x14RestoreBackupRequest\x12\x1f\n\tbackup_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12!\n\x0b\x64\x61tabase_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x18\n\x10paths_to_restore\x18\x03 \x03(\t\x12\x13\n\x0btarget_path\x18\x04 \x01(\t\"?\n\x15RestoreBackupMetadata\x12\x11\n\tbackup_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x02 \x01(\t\"j\n\x15\x42\x61\x63kupDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12<\n\x0f\x62\x61\x63kup_settings\x18\x02 \x01(\x0b\x32#.yandex.cloud.ydb.v1.BackupSettings\"@\n\x16\x42\x61\x63kupDatabaseMetadata\x12\x11\n\tbackup_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x02 \x01(\t\"9\n\x14StartDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"C\n\x15StartDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"8\n\x13StopDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"B\n\x14StopDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"7\n\x12GetDatabaseRequest\x12!\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"g\n\x14ListDatabasesRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x15ListDatabasesResponse\x12\x30\n\tdatabases\x18\x01 \x03(\x0b\x32\x1d.yandex.cloud.ydb.v1.Database\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xe6\x06\n\x15\x43reateDatabaseRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1a\n\x12resource_preset_id\x18\x04 \x01(\t\x12:\n\x0estorage_config\x18\x05 \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x06 \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\x07 \x01(\t\x12\x12\n\nsubnet_ids\x18\x08 \x03(\t\x12<\n\x0ezonal_database\x18\t \x01(\x0b\x32\".yandex.cloud.ydb.v1.ZonalDatabaseH\x00\x12\x42\n\x11regional_database\x18\n \x01(\x0b\x32%.yandex.cloud.ydb.v1.RegionalDatabaseH\x00\x12\x44\n\x12\x64\x65\x64icated_database\x18\r \x01(\x0b\x32&.yandex.cloud.ydb.v1.DedicatedDatabaseH\x00\x12\x46\n\x13serverless_database\x18\x0e \x01(\x0b\x32\'.yandex.cloud.ydb.v1.ServerlessDatabaseH\x00\x12\x19\n\x11\x61ssign_public_ips\x18\x0b \x01(\x08\x12\x13\n\x0blocation_id\x18\x0c \x01(\t\x12\x46\n\x06labels\x18\x0f \x03(\x0b\x32\x36.yandex.cloud.ydb.v1.CreateDatabaseRequest.LabelsEntry\x12\x38\n\rbackup_config\x18\x10 \x01(\x0b\x32!.yandex.cloud.ydb.v1.BackupConfig\x12@\n\x11monitoring_config\x18\x11 \x01(\x0b\x32%.yandex.cloud.ydb.v1.MonitoringConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x12 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rdatabase_type\"D\n\x16\x43reateDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\"\xac\x07\n\x15UpdateDatabaseRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x13\n\x0b\x64\x61tabase_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x1a\n\x12resource_preset_id\x18\x06 \x01(\t\x12:\n\x0estorage_config\x18\x07 \x01(\x0b\x32\".yandex.cloud.ydb.v1.StorageConfig\x12\x36\n\x0cscale_policy\x18\x08 \x01(\x0b\x32 .yandex.cloud.ydb.v1.ScalePolicy\x12\x12\n\nnetwork_id\x18\t \x01(\t\x12\x12\n\nsubnet_ids\x18\n \x03(\t\x12<\n\x0ezonal_database\x18\x0b \x01(\x0b\x32\".yandex.cloud.ydb.v1.ZonalDatabaseH\x00\x12\x42\n\x11regional_database\x18\x0c \x01(\x0b\x32%.yandex.cloud.ydb.v1.RegionalDatabaseH\x00\x12\x44\n\x12\x64\x65\x64icated_database\x18\x0f \x01(\x0b\x32&.yandex.cloud.ydb.v1.DedicatedDatabaseH\x00\x12\x46\n\x13serverless_database\x18\x10 \x01(\x0b\x32\'.yandex.cloud.ydb.v1.ServerlessDatabaseH\x00\x12\x19\n\x11\x61ssign_public_ips\x18\r \x01(\x08\x12\x13\n\x0blocation_id\x18\x0e \x01(\t\x12\x46\n\x06labels\x18\x11 \x03(\x0b\x32\x36.yandex.cloud.ydb.v1.UpdateDatabaseRequest.LabelsEntry\x12\x38\n\rbackup_config\x18\x12 \x01(\x0b\x32!.yandex.cloud.ydb.v1.BackupConfig\x12@\n\x11monitoring_config\x18\x13 \x01(\x0b\x32%.yandex.cloud.ydb.v1.MonitoringConfig\x12\x1b\n\x13\x64\x65letion_protection\x18\x14 \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\rdatabase_type\"D\n\x16UpdateDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\",\n\x15\x44\x65leteDatabaseRequest\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\"D\n\x16\x44\x65leteDatabaseMetadata\x12\x13\n\x0b\x64\x61tabase_id\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t2\x9a\x10\n\x0f\x44\x61tabaseService\x12v\n\x03Get\x12\'.yandex.cloud.ydb.v1.GetDatabaseRequest\x1a\x1d.yandex.cloud.ydb.v1.Database\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/ydb/v1/databases/{database_id}\x12x\n\x04List\x12).yandex.cloud.ydb.v1.ListDatabasesRequest\x1a*.yandex.cloud.ydb.v1.ListDatabasesResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/ydb/v1/databases\x12\x9b\x01\n\x06\x43reate\x12*.yandex.cloud.ydb.v1.CreateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"B\xb2\xd2*\"\n\x16\x43reateDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\x16\"\x11/ydb/v1/databases:\x01*\x12\xa9\x01\n\x06Update\x12*.yandex.cloud.ydb.v1.UpdateDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2*\"\n\x16UpdateDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02$2\x1f/ydb/v1/databases/{database_id}:\x01*\x12\xa9\x01\n\x05Start\x12).yandex.cloud.ydb.v1.StartDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"R\xb2\xd2*!\n\x15StartDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\'\"%/ydb/v1/databases/{database_id}:start\x12\xa5\x01\n\x04Stop\x12(.yandex.cloud.ydb.v1.StopDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"P\xb2\xd2* \n\x14StopDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02&\"$/ydb/v1/databases/{database_id}:stop\x12\xa8\x01\n\x04Move\x12(.yandex.cloud.ydb.v1.MoveDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"S\xb2\xd2* \n\x14MoveDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02)\"$/ydb/v1/databases/{database_id}:move:\x01*\x12u\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\x12\xa4\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"=\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xad\x01\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x12\xb3\x01\n\x06\x44\x65lete\x12*.yandex.cloud.ydb.v1.DeleteDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"Z\xb2\xd2*/\n\x16\x44\x65leteDatabaseMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/ydb/v1/databases/{database_id}\x12\xa2\x01\n\x07Restore\x12).yandex.cloud.ydb.v1.RestoreBackupRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2*!\n\x15RestoreBackupMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\x1e\"\x19/ydb/v1/databases:restore:\x01*\x12\xa2\x01\n\x06\x42\x61\x63kup\x12*.yandex.cloud.ydb.v1.BackupDatabaseRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2*\"\n\x16\x42\x61\x63kupDatabaseMetadata\x12\x08\x44\x61tabase\x82\xd3\xe4\x93\x02\x1d\"\x18/ydb/v1/databases:backup:\x01*BV\n\x17yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydbb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ydb.v1.database_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.ydb.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/ydb/v1;ydb'
  _MOVEDATABASEREQUEST.fields_by_name['database_id']._options = None
  _MOVEDATABASEREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _MOVEDATABASEREQUEST.fields_by_name['destination_folder_id']._options = None
  _MOVEDATABASEREQUEST.fields_by_name['destination_folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTOREBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _RESTOREBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RESTOREBACKUPREQUEST.fields_by_name['database_id']._options = None
  _RESTOREBACKUPREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STARTDATABASEREQUEST.fields_by_name['database_id']._options = None
  _STARTDATABASEREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _STOPDATABASEREQUEST.fields_by_name['database_id']._options = None
  _STOPDATABASEREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETDATABASEREQUEST.fields_by_name['database_id']._options = None
  _GETDATABASEREQUEST.fields_by_name['database_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTDATABASESREQUEST.fields_by_name['page_size']._options = None
  _LISTDATABASESREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTDATABASESREQUEST.fields_by_name['page_token']._options = None
  _LISTDATABASESREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _CREATEDATABASEREQUEST_LABELSENTRY._options = None
  _CREATEDATABASEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEDATABASEREQUEST_LABELSENTRY._options = None
  _UPDATEDATABASEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _DATABASESERVICE.methods_by_name['Get']._options = None
  _DATABASESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/ydb/v1/databases/{database_id}'
  _DATABASESERVICE.methods_by_name['List']._options = None
  _DATABASESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\023\022\021/ydb/v1/databases'
  _DATABASESERVICE.methods_by_name['Create']._options = None
  _DATABASESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\"\n\026CreateDatabaseMetadata\022\010Database\202\323\344\223\002\026\"\021/ydb/v1/databases:\001*'
  _DATABASESERVICE.methods_by_name['Update']._options = None
  _DATABASESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\"\n\026UpdateDatabaseMetadata\022\010Database\202\323\344\223\002$2\037/ydb/v1/databases/{database_id}:\001*'
  _DATABASESERVICE.methods_by_name['Start']._options = None
  _DATABASESERVICE.methods_by_name['Start']._serialized_options = b'\262\322*!\n\025StartDatabaseMetadata\022\010Database\202\323\344\223\002\'\"%/ydb/v1/databases/{database_id}:start'
  _DATABASESERVICE.methods_by_name['Stop']._options = None
  _DATABASESERVICE.methods_by_name['Stop']._serialized_options = b'\262\322* \n\024StopDatabaseMetadata\022\010Database\202\323\344\223\002&\"$/ydb/v1/databases/{database_id}:stop'
  _DATABASESERVICE.methods_by_name['Move']._options = None
  _DATABASESERVICE.methods_by_name['Move']._serialized_options = b'\262\322* \n\024MoveDatabaseMetadata\022\010Database\202\323\344\223\002)\"$/ydb/v1/databases/{database_id}:move:\001*'
  _DATABASESERVICE.methods_by_name['SetAccessBindings']._options = None
  _DATABASESERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty'
  _DATABASESERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _DATABASESERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty'
  _DATABASESERVICE.methods_by_name['Delete']._options = None
  _DATABASESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*/\n\026DeleteDatabaseMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/ydb/v1/databases/{database_id}'
  _DATABASESERVICE.methods_by_name['Restore']._options = None
  _DATABASESERVICE.methods_by_name['Restore']._serialized_options = b'\262\322*!\n\025RestoreBackupMetadata\022\010Database\202\323\344\223\002\036\"\031/ydb/v1/databases:restore:\001*'
  _DATABASESERVICE.methods_by_name['Backup']._options = None
  _DATABASESERVICE.methods_by_name['Backup']._serialized_options = b'\262\322*\"\n\026BackupDatabaseMetadata\022\010Database\202\323\344\223\002\035\"\030/ydb/v1/databases:backup:\001*'
  _globals['_MOVEDATABASEREQUEST']._serialized_start=340
  _globals['_MOVEDATABASEREQUEST']._serialized_end=441
  _globals['_MOVEDATABASEMETADATA']._serialized_start=443
  _globals['_MOVEDATABASEMETADATA']._serialized_end=509
  _globals['_RESTOREBACKUPREQUEST']._serialized_start=512
  _globals['_RESTOREBACKUPREQUEST']._serialized_end=649
  _globals['_RESTOREBACKUPMETADATA']._serialized_start=651
  _globals['_RESTOREBACKUPMETADATA']._serialized_end=714
  _globals['_BACKUPDATABASEREQUEST']._serialized_start=716
  _globals['_BACKUPDATABASEREQUEST']._serialized_end=822
  _globals['_BACKUPDATABASEMETADATA']._serialized_start=824
  _globals['_BACKUPDATABASEMETADATA']._serialized_end=888
  _globals['_STARTDATABASEREQUEST']._serialized_start=890
  _globals['_STARTDATABASEREQUEST']._serialized_end=947
  _globals['_STARTDATABASEMETADATA']._serialized_start=949
  _globals['_STARTDATABASEMETADATA']._serialized_end=1016
  _globals['_STOPDATABASEREQUEST']._serialized_start=1018
  _globals['_STOPDATABASEREQUEST']._serialized_end=1074
  _globals['_STOPDATABASEMETADATA']._serialized_start=1076
  _globals['_STOPDATABASEMETADATA']._serialized_end=1142
  _globals['_GETDATABASEREQUEST']._serialized_start=1144
  _globals['_GETDATABASEREQUEST']._serialized_end=1199
  _globals['_LISTDATABASESREQUEST']._serialized_start=1201
  _globals['_LISTDATABASESREQUEST']._serialized_end=1304
  _globals['_LISTDATABASESRESPONSE']._serialized_start=1306
  _globals['_LISTDATABASESRESPONSE']._serialized_end=1404
  _globals['_CREATEDATABASEREQUEST']._serialized_start=1407
  _globals['_CREATEDATABASEREQUEST']._serialized_end=2277
  _globals['_CREATEDATABASEREQUEST_LABELSENTRY']._serialized_start=2215
  _globals['_CREATEDATABASEREQUEST_LABELSENTRY']._serialized_end=2260
  _globals['_CREATEDATABASEMETADATA']._serialized_start=2279
  _globals['_CREATEDATABASEMETADATA']._serialized_end=2347
  _globals['_UPDATEDATABASEREQUEST']._serialized_start=2350
  _globals['_UPDATEDATABASEREQUEST']._serialized_end=3290
  _globals['_UPDATEDATABASEREQUEST_LABELSENTRY']._serialized_start=2215
  _globals['_UPDATEDATABASEREQUEST_LABELSENTRY']._serialized_end=2260
  _globals['_UPDATEDATABASEMETADATA']._serialized_start=3292
  _globals['_UPDATEDATABASEMETADATA']._serialized_end=3360
  _globals['_DELETEDATABASEREQUEST']._serialized_start=3362
  _globals['_DELETEDATABASEREQUEST']._serialized_end=3406
  _globals['_DELETEDATABASEMETADATA']._serialized_start=3408
  _globals['_DELETEDATABASEMETADATA']._serialized_end=3476
  _globals['_DATABASESERVICE']._serialized_start=3479
  _globals['_DATABASESERVICE']._serialized_end=5553
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.iot.devices.v1.registry_pb2
import yandex.cloud.iot.devices.v1.registry_service_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class RegistryServiceStub:
    """A set of methods for managing registry."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.GetRegistryRequest,
        yandex.cloud.iot.devices.v1.registry_pb2.Registry,
    ]
    """Returns the specified registry.

    To get the list of available registries, make a [List] request.
    """

    GetByName: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.GetByNameRegistryRequest,
        yandex.cloud.iot.devices.v1.registry_pb2.Registry,
    ]

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistriesRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistriesResponse,
    ]
    """Retrieves the list of registries in the specified folder."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.CreateRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a registry in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.UpdateRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified registry."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified registry."""

    ListCertificates: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryCertificatesRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryCertificatesResponse,
    ]
    """Retrieves the list of registry certificates for the specified registry."""

    AddCertificate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.AddRegistryCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a certificate."""

    DeleteCertificate: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteRegistryCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified registry certificate."""

    ListPasswords: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryPasswordsRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryPasswordsResponse,
    ]
    """Retrieves the list of passwords for the specified registry."""

    AddPassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.AddRegistryPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds password for the specified registry."""

    DeletePassword: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteRegistryPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified password."""

    ListDeviceTopicAliases: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListDeviceTopicAliasesRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListDeviceTopicAliasesResponse,
    ]
    """Retrieves the list of device topic aliases for the specified registry."""

    ListDataStreamExports: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListDataStreamExportsRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListDataStreamExportsResponse,
    ]
    """Retrieves the list of YDS exports for the specified registry."""

    AddDataStreamExport: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.AddDataStreamExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds YDS export for the specified registry."""

    DeleteDataStreamExport: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteDataStreamExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified YDS export."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryOperationsRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryOperationsResponse,
    ]
    """Lists operations for the specified registry."""

    Disable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DisableRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disables the specified registry."""

    Enable: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.EnableRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enables the specified registry."""

class RegistryServiceAsyncStub:
    """A set of methods for managing registry."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.GetRegistryRequest,
        yandex.cloud.iot.devices.v1.registry_pb2.Registry,
    ]
    """Returns the specified registry.

    To get the list of available registries, make a [List] request.
    """

    GetByName: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.GetByNameRegistryRequest,
        yandex.cloud.iot.devices.v1.registry_pb2.Registry,
    ]

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistriesRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistriesResponse,
    ]
    """Retrieves the list of registries in the specified folder."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.CreateRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a registry in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.UpdateRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified registry."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified registry."""

    ListCertificates: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryCertificatesRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryCertificatesResponse,
    ]
    """Retrieves the list of registry certificates for the specified registry."""

    AddCertificate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.AddRegistryCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds a certificate."""

    DeleteCertificate: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteRegistryCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified registry certificate."""

    ListPasswords: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryPasswordsRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryPasswordsResponse,
    ]
    """Retrieves the list of passwords for the specified registry."""

    AddPassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.AddRegistryPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds password for the specified registry."""

    DeletePassword: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteRegistryPasswordRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified password."""

    ListDeviceTopicAliases: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListDeviceTopicAliasesRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListDeviceTopicAliasesResponse,
    ]
    """Retrieves the list of device topic aliases for the specified registry."""

    ListDataStreamExports: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListDataStreamExportsRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListDataStreamExportsResponse,
    ]
    """Retrieves the list of YDS exports for the specified registry."""

    AddDataStreamExport: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.AddDataStreamExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds YDS export for the specified registry."""

    DeleteDataStreamExport: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteDataStreamExportRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified YDS export."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryOperationsRequest,
        yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryOperationsResponse,
    ]
    """Lists operations for the specified registry."""

    Disable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.DisableRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Disables the specified registry."""

    Enable: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.iot.devices.v1.registry_service_pb2.EnableRegistryRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Enables the specified registry."""

class RegistryServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing registry."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.GetRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.registry_pb2.Registry, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.registry_pb2.Registry]]:
        """Returns the specified registry.

        To get the list of available registries, make a [List] request.
        """

    @abc.abstractmethod
    def GetByName(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.GetByNameRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.registry_pb2.Registry, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.registry_pb2.Registry]]: ...

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistriesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistriesResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistriesResponse]]:
        """Retrieves the list of registries in the specified folder."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.CreateRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a registry in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.UpdateRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified registry."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified registry."""

    @abc.abstractmethod
    def ListCertificates(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryCertificatesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryCertificatesResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryCertificatesResponse]]:
        """Retrieves the list of registry certificates for the specified registry."""

    @abc.abstractmethod
    def AddCertificate(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.AddRegistryCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds a certificate."""

    @abc.abstractmethod
    def DeleteCertificate(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteRegistryCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified registry certificate."""

    @abc.abstractmethod
    def ListPasswords(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryPasswordsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryPasswordsResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryPasswordsResponse]]:
        """Retrieves the list of passwords for the specified registry."""

    @abc.abstractmethod
    def AddPassword(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.AddRegistryPasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds password for the specified registry."""

    @abc.abstractmethod
    def DeletePassword(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteRegistryPasswordRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified password."""

    @abc.abstractmethod
    def ListDeviceTopicAliases(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.ListDeviceTopicAliasesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.registry_service_pb2.ListDeviceTopicAliasesResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.registry_service_pb2.ListDeviceTopicAliasesResponse]]:
        """Retrieves the list of device topic aliases for the specified registry."""

    @abc.abstractmethod
    def ListDataStreamExports(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.ListDataStreamExportsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.registry_service_pb2.ListDataStreamExportsResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.registry_service_pb2.ListDataStreamExportsResponse]]:
        """Retrieves the list of YDS exports for the specified registry."""

    @abc.abstractmethod
    def AddDataStreamExport(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.AddDataStreamExportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds YDS export for the specified registry."""

    @abc.abstractmethod
    def DeleteDataStreamExport(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.DeleteDataStreamExportRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified YDS export."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryOperationsResponse, collections.abc.Awaitable[yandex.cloud.iot.devices.v1.registry_service_pb2.ListRegistryOperationsResponse]]:
        """Lists operations for the specified registry."""

    @abc.abstractmethod
    def Disable(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.DisableRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Disables the specified registry."""

    @abc.abstractmethod
    def Enable(
        self,
        request: yandex.cloud.iot.devices.v1.registry_service_pb2.EnableRegistryRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Enables the specified registry."""

def add_RegistryServiceServicer_to_server(servicer: RegistryServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.loadtesting.api.v1.test.agent_selector_pb2
import yandex.cloud.loadtesting.api.v1.test.file_pointer_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SingleAgentConfiguration(google.protobuf.message.Message):
    """Configuration of a test."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class FilesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> yandex.cloud.loadtesting.api.v1.test.file_pointer_pb2.FilePointer: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: yandex.cloud.loadtesting.api.v1.test.file_pointer_pb2.FilePointer | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CONFIG_ID_FIELD_NUMBER: builtins.int
    AGENT_SELECTOR_FIELD_NUMBER: builtins.int
    FILES_FIELD_NUMBER: builtins.int
    config_id: builtins.str
    """ID of the config."""
    @property
    def agent_selector(self) -> yandex.cloud.loadtesting.api.v1.test.agent_selector_pb2.AgentSelector:
        """Agent selection criterion."""

    @property
    def files(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, yandex.cloud.loadtesting.api.v1.test.file_pointer_pb2.FilePointer]:
        """Additional files to be used during test execution, represented as `rel_path:file` pairs.

        `rel_path` can be either a simple file name, a relative path, or absolute path. Files are
        downloaded by the agent to appropriate location.

        Use cases include:
        - [Test Data files](/docs/load-testing/concepts/payload).
        - Custom Pandora executable.
        - JMeter executable or ".jmx" scenario.
        - etc.
        """

    def __init__(
        self,
        *,
        config_id: builtins.str = ...,
        agent_selector: yandex.cloud.loadtesting.api.v1.test.agent_selector_pb2.AgentSelector | None = ...,
        files: collections.abc.Mapping[builtins.str, yandex.cloud.loadtesting.api.v1.test.file_pointer_pb2.FilePointer] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["agent_selector", b"agent_selector"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["agent_selector", b"agent_selector", "config_id", b"config_id", "files", b"files"]) -> None: ...

global___SingleAgentConfiguration = SingleAgentConfiguration



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ScanResult(google.protobuf.message.Message):
    """A ScanResult resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[ScanResult._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: ScanResult._Status.ValueType  # 0
        RUNNING: ScanResult._Status.ValueType  # 1
        """Image scan is in progress."""
        READY: ScanResult._Status.ValueType  # 2
        """Image has been scanned and result is ready."""
        ERROR: ScanResult._Status.ValueType  # 3
        """Image scan is failed."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: ScanResult.Status.ValueType  # 0
    RUNNING: ScanResult.Status.ValueType  # 1
    """Image scan is in progress."""
    READY: ScanResult.Status.ValueType  # 2
    """Image has been scanned and result is ready."""
    ERROR: ScanResult.Status.ValueType  # 3
    """Image scan is failed."""

    ID_FIELD_NUMBER: builtins.int
    IMAGE_ID_FIELD_NUMBER: builtins.int
    SCANNED_AT_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    VULNERABILITIES_FIELD_NUMBER: builtins.int
    id: builtins.str
    """Output only. ID of the ScanResult."""
    image_id: builtins.str
    """Output only. ID of the Image that the ScanResult belongs to."""
    status: global___ScanResult.Status.ValueType
    """Output only. The status of the ScanResult."""
    @property
    def scanned_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Output only. The timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format when the scan been finished."""

    @property
    def vulnerabilities(self) -> global___VulnerabilityStats:
        """Output only. Summary information about vulnerabilities found."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        image_id: builtins.str = ...,
        scanned_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        status: global___ScanResult.Status.ValueType = ...,
        vulnerabilities: global___VulnerabilityStats | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scanned_at", b"scanned_at", "vulnerabilities", b"vulnerabilities"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["id", b"id", "image_id", b"image_id", "scanned_at", b"scanned_at", "status", b"status", "vulnerabilities", b"vulnerabilities"]) -> None: ...

global___ScanResult = ScanResult

@typing.final
class VulnerabilityStats(google.protobuf.message.Message):
    """A VulnerabilityStats resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRITICAL_FIELD_NUMBER: builtins.int
    HIGH_FIELD_NUMBER: builtins.int
    MEDIUM_FIELD_NUMBER: builtins.int
    LOW_FIELD_NUMBER: builtins.int
    NEGLIGIBLE_FIELD_NUMBER: builtins.int
    UNDEFINED_FIELD_NUMBER: builtins.int
    critical: builtins.int
    """Count of CRITICAL vulnerabilities."""
    high: builtins.int
    """Count of HIGH vulnerabilities."""
    medium: builtins.int
    """Count of MEDIUM vulnerabilities."""
    low: builtins.int
    """Count of LOW vulnerabilities."""
    negligible: builtins.int
    """Count of NEGLIGIBLE vulnerabilities."""
    undefined: builtins.int
    """Count of other vulnerabilities."""
    def __init__(
        self,
        *,
        critical: builtins.int = ...,
        high: builtins.int = ...,
        medium: builtins.int = ...,
        low: builtins.int = ...,
        negligible: builtins.int = ...,
        undefined: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["critical", b"critical", "high", b"high", "low", b"low", "medium", b"medium", "negligible", b"negligible", "undefined", b"undefined"]) -> None: ...

global___VulnerabilityStats = VulnerabilityStats

@typing.final
class Vulnerability(google.protobuf.message.Message):
    """A Vulnerability resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Severity:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _SeverityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Vulnerability._Severity.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        SEVERITY_UNSPECIFIED: Vulnerability._Severity.ValueType  # 0
        CRITICAL: Vulnerability._Severity.ValueType  # 1
        """Critical severity is a world-burning problem, exploitable for nearly all users.
        Includes remote root privilege escalations, or massive data loss.
        """
        HIGH: Vulnerability._Severity.ValueType  # 2
        """High severity is a real problem, exploitable for many users in a default installation.
        Includes serious remote denial of services, local root privilege escalations, or data loss.
        """
        MEDIUM: Vulnerability._Severity.ValueType  # 3
        """Medium severity is a real security problem, and is exploitable for many users.
        Includes network daemon denial of service attacks, cross-site scripting, and gaining user privileges.
        Updates should be made soon for this priority of issue.
        """
        LOW: Vulnerability._Severity.ValueType  # 4
        """Low severity is a security problem, but is hard to exploit due to environment, requires a user-assisted attack,
        a small install base, or does very little damage. These tend to be included in security updates only when
        higher priority issues require an update, or if many low priority issues have built up.
        """
        NEGLIGIBLE: Vulnerability._Severity.ValueType  # 5
        """Negligible severity is technically a security problem, but is only theoretical in nature, requires a very special situation,
        has almost no install base, or does no real damage. These tend not to get backport from upstream,
        and will likely not be included in security updates unless there is an easy fix and some other issue causes an update.
        """
        UNDEFINED: Vulnerability._Severity.ValueType  # 6
        """Unknown severity is either a security problem that has not been assigned to a priority yet or
        a priority that our system did not recognize.
        """

    class Severity(_Severity, metaclass=_SeverityEnumTypeWrapper): ...
    SEVERITY_UNSPECIFIED: Vulnerability.Severity.ValueType  # 0
    CRITICAL: Vulnerability.Severity.ValueType  # 1
    """Critical severity is a world-burning problem, exploitable for nearly all users.
    Includes remote root privilege escalations, or massive data loss.
    """
    HIGH: Vulnerability.Severity.ValueType  # 2
    """High severity is a real problem, exploitable for many users in a default installation.
    Includes serious remote denial of services, local root privilege escalations, or data loss.
    """
    MEDIUM: Vulnerability.Severity.ValueType  # 3
    """Medium severity is a real security problem, and is exploitable for many users.
    Includes network daemon denial of service attacks, cross-site scripting, and gaining user privileges.
    Updates should be made soon for this priority of issue.
    """
    LOW: Vulnerability.Severity.ValueType  # 4
    """Low severity is a security problem, but is hard to exploit due to environment, requires a user-assisted attack,
    a small install base, or does very little damage. These tend to be included in security updates only when
    higher priority issues require an update, or if many low priority issues have built up.
    """
    NEGLIGIBLE: Vulnerability.Severity.ValueType  # 5
    """Negligible severity is technically a security problem, but is only theoretical in nature, requires a very special situation,
    has almost no install base, or does no real damage. These tend not to get backport from upstream,
    and will likely not be included in security updates unless there is an easy fix and some other issue causes an update.
    """
    UNDEFINED: Vulnerability.Severity.ValueType  # 6
    """Unknown severity is either a security problem that has not been assigned to a priority yet or
    a priority that our system did not recognize.
    """

    SEVERITY_FIELD_NUMBER: builtins.int
    PACKAGE_FIELD_NUMBER: builtins.int
    severity: global___Vulnerability.Severity.ValueType
    """Output only. Severity of the Vulnerability."""
    @property
    def package(self) -> global___PackageVulnerability: ...
    def __init__(
        self,
        *,
        severity: global___Vulnerability.Severity.ValueType = ...,
        package: global___PackageVulnerability | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["package", b"package", "vulnerability", b"vulnerability"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["package", b"package", "severity", b"severity", "vulnerability", b"vulnerability"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["vulnerability", b"vulnerability"]) -> typing.Literal["package"] | None: ...

global___Vulnerability = Vulnerability

@typing.final
class PackageVulnerability(google.protobuf.message.Message):
    """A PackageVulnerability resource."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    LINK_FIELD_NUMBER: builtins.int
    PACKAGE_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    FIXED_BY_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of vulnerability in CVE database."""
    link: builtins.str
    """URL to the page with description of vulnerability."""
    package: builtins.str
    """The package name where vulnerability has been found."""
    source: builtins.str
    """The package manager name. Ex.: yum, rpm, dpkg."""
    version: builtins.str
    """The version of the package where vulnerability has been found."""
    fixed_by: builtins.str
    """The version of the package where vulnerability has been fixed."""
    origin: builtins.str
    """The place where vulnerability is originated (OS, lang package, etc.)"""
    type: builtins.str
    """The type of vulnerability origin - name of OS if origin="os" or package type (jar, gobinary, etc.) if origin="lang" """
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        link: builtins.str = ...,
        package: builtins.str = ...,
        source: builtins.str = ...,
        version: builtins.str = ...,
        fixed_by: builtins.str = ...,
        origin: builtins.str = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["fixed_by", b"fixed_by", "link", b"link", "name", b"name", "origin", b"origin", "package", b"package", "source", b"source", "type", b"type", "version", b"version"]) -> None: ...

global___PackageVulnerability = PackageVulnerability



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/vision/v2/image_classifier_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.ai.vision.v2 import image_classifier_pb2 as yandex_dot_cloud_dot_ai_dot_vision_dot_v2_dot_image__classifier__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8yandex/cloud/ai/vision/v2/image_classifier_service.proto\x12\x19yandex.cloud.ai.vision.v2\x1a\x30yandex/cloud/ai/vision/v2/image_classifier.proto2\x83\x01\n\x16ImageClassifierService\x12i\n\x08\x41nnotate\x12,.yandex.cloud.ai.vision.v2.AnnotationRequest\x1a-.yandex.cloud.ai.vision.v2.AnnotationResponse\"\x00\x42\x65\n\x1dyandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;visionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.vision.v2.image_classifier_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;vision'
  _globals['_IMAGECLASSIFIERSERVICE']._serialized_start=138
  _globals['_IMAGECLASSIFIERSERVICE']._serialized_end=269
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/smartwebsecurity/v1/security_profile_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.smartwebsecurity.v1 import security_profile_pb2 as yandex_dot_cloud_dot_smartwebsecurity_dot_v1_dot_security__profile__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/smartwebsecurity/v1/security_profile_service.proto\x12 yandex.cloud.smartwebsecurity.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x37yandex/cloud/smartwebsecurity/v1/security_profile.proto\">\n\x19GetSecurityProfileRequest\x12!\n\x13security_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x1bListSecurityProfilesRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"l\n\x1cListSecurityProfilesResponse\x12L\n\x11security_profiles\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.smartwebsecurity.v1.SecurityProfile\"\x9a\x03\n\x1c\x43reateSecurityProfileRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12Z\n\x06labels\x18\x02 \x03(\x0b\x32J.yandex.cloud.smartwebsecurity.v1.CreateSecurityProfileRequest.LabelsEntry\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12W\n\x0e\x64\x65\x66\x61ult_action\x18\x05 \x01(\x0e\x32?.yandex.cloud.smartwebsecurity.v1.SecurityProfile.DefaultAction\x12\x46\n\x0esecurity_rules\x18\x06 \x03(\x0b\x32..yandex.cloud.smartwebsecurity.v1.SecurityRule\x12\x12\n\ncaptcha_id\x18\x07 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x1d\x43reateSecurityProfileMetadata\x12\x1b\n\x13security_profile_id\x18\x01 \x01(\t\"\xd5\x03\n\x1cUpdateSecurityProfileRequest\x12!\n\x13security_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12Z\n\x06labels\x18\x03 \x03(\x0b\x32J.yandex.cloud.smartwebsecurity.v1.UpdateSecurityProfileRequest.LabelsEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12W\n\x0e\x64\x65\x66\x61ult_action\x18\x06 \x01(\x0e\x32?.yandex.cloud.smartwebsecurity.v1.SecurityProfile.DefaultAction\x12\x46\n\x0esecurity_rules\x18\x07 \x03(\x0b\x32..yandex.cloud.smartwebsecurity.v1.SecurityRule\x12\x12\n\ncaptcha_id\x18\x08 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"<\n\x1dUpdateSecurityProfileMetadata\x12\x1b\n\x13security_profile_id\x18\x01 \x01(\t\"A\n\x1c\x44\x65leteSecurityProfileRequest\x12!\n\x13security_profile_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"<\n\x1d\x44\x65leteSecurityProfileMetadata\x12\x1b\n\x13security_profile_id\x18\x01 \x01(\t2\xb7\x08\n\x16SecurityProfileService\x12\xba\x01\n\x03Get\x12;.yandex.cloud.smartwebsecurity.v1.GetSecurityProfileRequest\x1a\x31.yandex.cloud.smartwebsecurity.v1.SecurityProfile\"C\x82\xd3\xe4\x93\x02=\x12;/smartwebsecurity/v1/securityProfiles/{security_profile_id}\x12\xb4\x01\n\x04List\x12=.yandex.cloud.smartwebsecurity.v1.ListSecurityProfilesRequest\x1a>.yandex.cloud.smartwebsecurity.v1.ListSecurityProfilesResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/smartwebsecurity/v1/securityProfiles\x12\xd1\x01\n\x06\x43reate\x12>.yandex.cloud.smartwebsecurity.v1.CreateSecurityProfileRequest\x1a!.yandex.cloud.operation.Operation\"d\xb2\xd2*0\n\x1d\x43reateSecurityProfileMetadata\x12\x0fSecurityProfile\x82\xd3\xe4\x93\x02*\"%/smartwebsecurity/v1/securityProfiles:\x01*\x12\xe7\x01\n\x06Update\x12>.yandex.cloud.smartwebsecurity.v1.UpdateSecurityProfileRequest\x1a!.yandex.cloud.operation.Operation\"z\xb2\xd2*0\n\x1dUpdateSecurityProfileMetadata\x12\x0fSecurityProfile\x82\xd3\xe4\x93\x02@2;/smartwebsecurity/v1/securityProfiles/{security_profile_id}:\x01*\x12\xea\x01\n\x06\x44\x65lete\x12>.yandex.cloud.smartwebsecurity.v1.DeleteSecurityProfileRequest\x1a!.yandex.cloud.operation.Operation\"}\xb2\xd2*6\n\x1d\x44\x65leteSecurityProfileMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02=*;/smartwebsecurity/v1/securityProfiles/{security_profile_id}B}\n$yandex.cloud.api.smartwebsecurity.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1;smartwebsecurityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.smartwebsecurity.v1.security_profile_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n$yandex.cloud.api.smartwebsecurity.v1ZUgithub.com/yandex-cloud/go-genproto/yandex/cloud/smartwebsecurity/v1;smartwebsecurity'
  _GETSECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._options = None
  _GETSECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._serialized_options = b'\350\3071\001'
  _LISTSECURITYPROFILESREQUEST.fields_by_name['folder_id']._options = None
  _LISTSECURITYPROFILESREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _CREATESECURITYPROFILEREQUEST_LABELSENTRY._options = None
  _CREATESECURITYPROFILEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _CREATESECURITYPROFILEREQUEST.fields_by_name['folder_id']._options = None
  _CREATESECURITYPROFILEREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001'
  _UPDATESECURITYPROFILEREQUEST_LABELSENTRY._options = None
  _UPDATESECURITYPROFILEREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATESECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._options = None
  _UPDATESECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._serialized_options = b'\350\3071\001'
  _DELETESECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._options = None
  _DELETESECURITYPROFILEREQUEST.fields_by_name['security_profile_id']._serialized_options = b'\350\3071\001'
  _SECURITYPROFILESERVICE.methods_by_name['Get']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002=\022;/smartwebsecurity/v1/securityProfiles/{security_profile_id}'
  _SECURITYPROFILESERVICE.methods_by_name['List']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\'\022%/smartwebsecurity/v1/securityProfiles'
  _SECURITYPROFILESERVICE.methods_by_name['Create']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['Create']._serialized_options = b'\262\322*0\n\035CreateSecurityProfileMetadata\022\017SecurityProfile\202\323\344\223\002*\"%/smartwebsecurity/v1/securityProfiles:\001*'
  _SECURITYPROFILESERVICE.methods_by_name['Update']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['Update']._serialized_options = b'\262\322*0\n\035UpdateSecurityProfileMetadata\022\017SecurityProfile\202\323\344\223\002@2;/smartwebsecurity/v1/securityProfiles/{security_profile_id}:\001*'
  _SECURITYPROFILESERVICE.methods_by_name['Delete']._options = None
  _SECURITYPROFILESERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*6\n\035DeleteSecurityProfileMetadata\022\025google.protobuf.Empty\202\323\344\223\002=*;/smartwebsecurity/v1/securityProfiles/{security_profile_id}'
  _globals['_GETSECURITYPROFILEREQUEST']._serialized_start=327
  _globals['_GETSECURITYPROFILEREQUEST']._serialized_end=389
  _globals['_LISTSECURITYPROFILESREQUEST']._serialized_start=391
  _globals['_LISTSECURITYPROFILESREQUEST']._serialized_end=445
  _globals['_LISTSECURITYPROFILESRESPONSE']._serialized_start=447
  _globals['_LISTSECURITYPROFILESRESPONSE']._serialized_end=555
  _globals['_CREATESECURITYPROFILEREQUEST']._serialized_start=558
  _globals['_CREATESECURITYPROFILEREQUEST']._serialized_end=968
  _globals['_CREATESECURITYPROFILEREQUEST_LABELSENTRY']._serialized_start=923
  _globals['_CREATESECURITYPROFILEREQUEST_LABELSENTRY']._serialized_end=968
  _globals['_CREATESECURITYPROFILEMETADATA']._serialized_start=970
  _globals['_CREATESECURITYPROFILEMETADATA']._serialized_end=1030
  _globals['_UPDATESECURITYPROFILEREQUEST']._serialized_start=1033
  _globals['_UPDATESECURITYPROFILEREQUEST']._serialized_end=1502
  _globals['_UPDATESECURITYPROFILEREQUEST_LABELSENTRY']._serialized_start=923
  _globals['_UPDATESECURITYPROFILEREQUEST_LABELSENTRY']._serialized_end=968
  _globals['_UPDATESECURITYPROFILEMETADATA']._serialized_start=1504
  _globals['_UPDATESECURITYPROFILEMETADATA']._serialized_end=1564
  _globals['_DELETESECURITYPROFILEREQUEST']._serialized_start=1566
  _globals['_DELETESECURITYPROFILEREQUEST']._serialized_end=1631
  _globals['_DELETESECURITYPROFILEMETADATA']._serialized_start=1633
  _globals['_DELETESECURITYPROFILEMETADATA']._serialized_end=1693
  _globals['_SECURITYPROFILESERVICE']._serialized_start=1696
  _globals['_SECURITYPROFILESERVICE']._serialized_end=2775
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.kms.v1.asymmetricsignature import asymmetric_signature_key_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2
from yandex.cloud.kms.v1.asymmetricsignature import asymmetric_signature_key_service_pb2 as yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class AsymmetricSignatureKeyServiceStub(object):
    """Set of methods for managing asymmetric signature keys.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Create = channel.unary_unary(
                '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/Create',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.CreateAsymmetricSignatureKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Get = channel.unary_unary(
                '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/Get',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.GetAsymmetricSignatureKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2.AsymmetricSignatureKey.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/List',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeysRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeysResponse.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/Update',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.UpdateAsymmetricSignatureKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/Delete',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.DeleteAsymmetricSignatureKeyRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeyOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeyOperationsResponse.FromString,
                )
        self.ListAccessBindings = channel.unary_unary(
                '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/ListAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
                )
        self.SetAccessBindings = channel.unary_unary(
                '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/SetAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateAccessBindings = channel.unary_unary(
                '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/UpdateAccessBindings',
                request_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class AsymmetricSignatureKeyServiceServicer(object):
    """Set of methods for managing asymmetric signature keys.
    """

    def Create(self, request, context):
        """control plane
        Creates an asymmetric KMS key in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Get(self, request, context):
        """Returns the specified asymmetric KMS key.

        To get the list of available asymmetric KMS keys, make a [SymmetricKeyService.List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Returns the list of asymmetric KMS keys in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified asymmetric KMS key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified asymmetric KMS key. This action also automatically schedules
        the destruction of all of the key's versions in 72 hours.

        The key and its versions appear absent in [AsymmetricSignatureKeyService.Get] and [AsymmetricSignatureKeyService.List]
        requests, but can be restored within 72 hours with a request to tech support.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified asymmetric KMS key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAccessBindings(self, request, context):
        """Lists existing access bindings for the specified key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAccessBindings(self, request, context):
        """Sets access bindings for the key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateAccessBindings(self, request, context):
        """Updates access bindings for the specified key.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AsymmetricSignatureKeyServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.CreateAsymmetricSignatureKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.GetAsymmetricSignatureKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2.AsymmetricSignatureKey.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeysRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeysResponse.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.UpdateAsymmetricSignatureKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.DeleteAsymmetricSignatureKeyRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeyOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeyOperationsResponse.SerializeToString,
            ),
            'ListAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.SerializeToString,
            ),
            'SetAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateAccessBindings': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateAccessBindings,
                    request_deserializer=yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class AsymmetricSignatureKeyService(object):
    """Set of methods for managing asymmetric signature keys.
    """

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/Create',
            yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.CreateAsymmetricSignatureKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/Get',
            yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.GetAsymmetricSignatureKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__pb2.AsymmetricSignatureKey.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/List',
            yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeysRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeysResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/Update',
            yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.UpdateAsymmetricSignatureKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/Delete',
            yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.DeleteAsymmetricSignatureKeyRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/ListOperations',
            yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeyOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_kms_dot_v1_dot_asymmetricsignature_dot_asymmetric__signature__key__service__pb2.ListAsymmetricSignatureKeyOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/ListAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_access_dot_access__pb2.ListAccessBindingsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/SetAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.SetAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateAccessBindings(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.kms.v1.asymmetricsignature.AsymmetricSignatureKeyService/UpdateAccessBindings',
            yandex_dot_cloud_dot_access_dot_access__pb2.UpdateAccessBindingsRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SerializerAuto(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SerializerAuto = SerializerAuto

@typing.final
class SerializerJSON(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SerializerJSON = SerializerJSON

@typing.final
class DebeziumSerializerParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    key: builtins.str
    """Name of the serializer parameter"""
    value: builtins.str
    """Value of the serializer parameter"""
    def __init__(
        self,
        *,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

global___DebeziumSerializerParameter = DebeziumSerializerParameter

@typing.final
class SerializerDebezium(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERIALIZER_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def serializer_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DebeziumSerializerParameter]:
        """Settings of sterilization parameters as key-value pairs"""

    def __init__(
        self,
        *,
        serializer_parameters: collections.abc.Iterable[global___DebeziumSerializerParameter] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["serializer_parameters", b"serializer_parameters"]) -> None: ...

global___SerializerDebezium = SerializerDebezium

@typing.final
class Serializer(google.protobuf.message.Message):
    """Data serialization format"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERIALIZER_AUTO_FIELD_NUMBER: builtins.int
    SERIALIZER_JSON_FIELD_NUMBER: builtins.int
    SERIALIZER_DEBEZIUM_FIELD_NUMBER: builtins.int
    @property
    def serializer_auto(self) -> global___SerializerAuto:
        """Select the serialization format automatically"""

    @property
    def serializer_json(self) -> global___SerializerJSON:
        """Serialize data in json format"""

    @property
    def serializer_debezium(self) -> global___SerializerDebezium:
        """Serialize data in debezium format"""

    def __init__(
        self,
        *,
        serializer_auto: global___SerializerAuto | None = ...,
        serializer_json: global___SerializerJSON | None = ...,
        serializer_debezium: global___SerializerDebezium | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["serializer", b"serializer", "serializer_auto", b"serializer_auto", "serializer_debezium", b"serializer_debezium", "serializer_json", b"serializer_json"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["serializer", b"serializer", "serializer_auto", b"serializer_auto", "serializer_debezium", b"serializer_debezium", "serializer_json", b"serializer_json"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["serializer", b"serializer"]) -> typing.Literal["serializer_auto", "serializer_json", "serializer_debezium"] | None: ...

global___Serializer = Serializer
